
local MakePlayerCharacter = require "prefabs/player_common"


local assets = {
    Asset("SCRIPT", "scripts/prefabs/player_common.lua"),
    Asset("ANIM", "anim/girl_rolling.zip"),
	Asset("ANIM", "anim/amber.zip"),
	Asset("ANIM", "anim/amber_hair1.zip"),
	Asset("ANIM", "anim/amber_hair2.zip"),
	Asset("ANIM", "anim/amber_hair3.zip"),
}
local prefabs = {}

-- Custom starting items
local start_inv = {

}

local common_postinit = function(inst) 
	inst.MiniMapEntity:SetIcon( "amber.tex" )
	inst:AddTag("bearded")
	inst:AddTag("monster")
end

local function OnResetHair(inst)
    inst.AnimState:OverrideSymbol("headbase", "amber", "headbase")
	inst.AnimState:OverrideSymbol("headbase_hat", "amber", "headbase_hat")
end

local HAIR_DAYS = { 4, 8, 16 } -- Hair days 
local HAIR_BITS = { 1, 3,  9 } -- Hair count

local function OnGrowShortHair(inst)
    inst.AnimState:OverrideSymbol("headbase", "amber_hair1", "headbase")
	inst.AnimState:OverrideSymbol("headbase_hat", "amber_hair1", "headbase_hat")
    inst.components.beard.bits = HAIR_BITS[1]
end

local function OnGrowMediumHair(inst)
    inst.AnimState:OverrideSymbol("headbase", "amber_hair2", "headbase")
	inst.AnimState:OverrideSymbol("headbase_hat", "amber_hair2", "headbase_hat")
    inst.components.beard.bits = HAIR_BITS[2]
end

local function OnGrowLongHair(inst)
    inst.AnimState:OverrideSymbol("headbase", "amber_hair3", "headbase")
	inst.AnimState:OverrideSymbol("headbase_hat", "amber_hair3", "headbase_hat")
    inst.components.beard.bits = HAIR_BITS[3]
end

local function OnTimerDone(inst, data)
    local is_moving = inst.sg and inst.sg:HasStateTag("running")
    if data.name == "walk" and is_moving and not inst:HasTag("playerghost") and not inst:HasTag("groggy") and inst.components.carefulwalker.careful == false and TUNING.AMBER_ROLLING == 0 then
	    inst:AddTag("rolling")
       	inst.AnimState:SetBank("girl_rolling")
		inst.AnimState:SetBuild("girl_rolling")
		inst.AnimState:PlayAnimation("run_loop", true)
		inst:RemoveEventCallback("timerdone", OnTimerDone)
	    inst:ListenForEvent("timerdone", OnTimerDone)
	    inst.components.timer:StartTimer("hard_roll", 7)
    end
    if data.name == "hard_roll" and is_moving and not inst:HasTag("playerghost") and not inst:HasTag("groggy") and inst.components.carefulwalker.careful == false and inst:HasTag("rolling") then
	    inst:AddTag("hard_roll")
		inst:RemoveEventCallback("timerdone", OnTimerDone)
    end
end

local function check_any_time(inst)
    local is_moving = inst.sg and inst.sg:HasStateTag("running")
	if is_moving and not inst:HasTag("start_walk") then
	    inst:AddTag("start_walk")
	    inst:ListenForEvent("timerdone", OnTimerDone)
	    inst.components.timer:StartTimer("walk", 3)
	end
	
	if inst:HasTag("rolling") and (inst:HasTag("groggy") or inst.components.carefulwalker.careful == true) then
	    inst:RemoveTag("rolling")
		inst:RemoveTag("hard_roll")
		inst:RemoveEventCallback("timerdone", OnTimerDone)
	    inst.AnimState:SetBank("wilson")
		inst.AnimState:SetBuild("amber")
        inst.components.locomotor:Stop()
		inst.components.locomotor:Clear()
		inst.components.locomotor.walkspeed = 5
	    inst.components.locomotor.runspeed = 5
	end
	
	if inst:HasTag("rolling") and not inst:HasTag("hard_roll")then
        inst.components.hunger:DoDelta(-0.02, true, true)
	    inst.components.locomotor.walkspeed = 8
	    inst.components.locomotor.runspeed = 8
	end
	
	if inst:HasTag("rolling") and inst:HasTag("hard_roll") then
        inst.components.hunger:DoDelta(-0.04, true, true)
	    inst.components.locomotor.walkspeed = 10
	    inst.components.locomotor.runspeed = 10
	end

	if not is_moving and not inst:HasTag("playerghost") then
		inst:RemoveTag("start_walk")
		inst:RemoveTag("rolling")
		inst:RemoveTag("hard_roll")
		inst:RemoveEventCallback("timerdone", OnTimerDone)
	    inst.AnimState:SetBank("wilson")
		inst.AnimState:SetBuild("amber")
	    inst.components.locomotor.walkspeed = 5
	    inst.components.locomotor.runspeed = 5
	end
	--Prints for debugs.
	--print("Speed - "..inst.components.locomotor.walkspeed)
	--print("Hunger - "..inst.components.hunger.current)
    if inst.components.inventory and inst.components.inventory:GetEquippedItem(EQUIPSLOTS.HANDS) and inst.components.inventory:GetEquippedItem(EQUIPSLOTS.HANDS):HasTag("magic_trash") then
	    local item = inst.components.inventory:GetEquippedItem(EQUIPSLOTS.HANDS)
		inst.components.inventory:Unequip(EQUIPSLOTS.HANDS, true) 
        inst.components.inventory:DropItem(item)
		inst.components.talker:Say("Trash!")
	end
    if inst.components.inventory and inst.components.inventory:GetEquippedItem(EQUIPSLOTS.BODY) and inst.components.inventory:GetEquippedItem(EQUIPSLOTS.BODY):HasTag("magic_trash") then
	    local item = inst.components.inventory:GetEquippedItem(EQUIPSLOTS.BODY)
		inst.components.inventory:Unequip(EQUIPSLOTS.BODY, true) 
        inst.components.inventory:DropItem(item)
		inst.components.talker:Say("Trash!")
	end
end
	
local master_postinit = function(inst)

	inst.components.locomotor.walkspeed = 5
	inst.components.locomotor.runspeed = 5

	inst.soundsname = "willow"
	
	inst.components.health:SetMaxHealth(TUNING.AMBER_HP)
	inst.components.hunger:SetMax(TUNING.AMBER_HUN)
	inst.components.sanity:SetMax(TUNING.AMBER_SANITY)
	
    inst.components.combat.damagemultiplier = 1.25
	
	inst.components.hunger.hungerrate = 1 * TUNING.WILSON_HUNGER_RATE
	
	inst.components.sanity.night_drain_mult = TUNING.WENDY_SANITY_MULT
	
	inst:AddComponent("timer")

	
	inst:DoPeriodicTask(0, check_any_time)
	
    inst:AddComponent("beard")
    inst.components.beard.onreset = OnResetHair
    inst.components.beard.prize = "beardhair"
    inst.components.beard:AddCallback(HAIR_DAYS[1], OnGrowShortHair)
    inst.components.beard:AddCallback(HAIR_DAYS[2], OnGrowMediumHair)
    inst.components.beard:AddCallback(HAIR_DAYS[3], OnGrowLongHair)
	
    inst.components.eater.stale_hunger = TUNING.WICKERBOTTOM_STALE_FOOD_HUNGER
    inst.components.eater.stale_health = TUNING.WICKERBOTTOM_STALE_FOOD_HEALTH
    inst.components.eater.spoiled_hunger = TUNING.WICKERBOTTOM_SPOILED_FOOD_HUNGER
    inst.components.eater.spoiled_health = TUNING.WICKERBOTTOM_SPOILED_FOOD_HEALTH
	
end

return MakePlayerCharacter("amber", prefabs, assets, common_postinit, master_postinit, start_inv)
